function[P] = scatter(n,V,E,a ,b)
%%Solves for the probability density of a particle in a scattering state
%%within a finite interval. Uses a first order approximation of the
%%derivative for the boundary conditions.
%% n: the step size
%% V: handle to a potential function
%% E: The energy of the particle
%% a: Left bound of the interval
%% b: Right bound of the interval

% close all

dx = (b-a)/ (n-1);
term13 = -(1 / dx^2);
term2 = (2 / dx^2) - E;

%Create our matrix h, and xval for plotting
xval = zeros(n,1);
H = zeros(n,n);

%Properly create the first row, this has index j and x = a
H(1,1) = (-1/dx) - 1i*kfun(a,E,V);
H(1,2) = 1/dx;
xval(1) = a;

%Properly create the last row, this has index n, and x = b
H(n,n-1) = 1/dx;
H(n,n) = 1i*kfun(b,E,V) - (1/dx);
xval(n) = b;

%Create the b-vector, which is all zeros except for the first entry
b = zeros(n,1);
b(1) = -2i * kfun(a,E,V) * exp(-1i * kfun(a,E,V) * a);

for j = 2:n-1
    %Ensure the first entry does not result in an error
    H(j,j-1) = term13;
    
    H(j,j+1) = term13;
    
    H(j,j) = term2 + V(a+(j-1)*dx);    
    xval(j) = (a + (j-1) * dx);
end
%solve for U and get the probability density
U = H\b;
P = (U.*conj(U));

%P scales by the step size, this is akin to normalizing the wave
P = P/max(P);

%Use to plot from inside the function
%plot(xval,(P/max(P)),'b');
