function[] = schrod(n, V, a, b)
%%Gives a numerical solution to the Schrodinger equation. 
%% n: The number of sample nodes
%% V: handle to a potential function defined on the interval (0,1
%% a: The left side of the interval
%% b: The right side of the interval


%We begin by creating the Schrodinger matrix H to solve
%                       Hu = Eu
close all
%Preset several values to speed up matrix calculation
dx = (b-a)/ (n+1);
term13 = -(1 / dx^2);
term2 = (2 / dx^2);

xval = zeros(n,1);
vval = zeros(n,1);

H = zeros(n,n);
for j = 1:n
    %Ensure the first entry does not result in an error
    if j-1>0
        H(j,j-1) = term13;
    end
    
    %Ensure the last entry does not result in an error
    if j+1< n+1
        H(j,j+1) = term13;
    end
    
    %The second term cannot result in an error
    H(j,j) = term2 + V(a + j*dx);    
    vval(j) = V(a + j*dx);
    xval(j) = (a + j * dx);
end

%Get the eigenvectors and eigenvalues of the Schrodinger Matrix
%E: The Energy (eigenvalues)
%U: A matrix for which each column is an eigenvector (wavefunction)
[U,E] = eig(H);

%Normalize each vector
for m = 1:n
    U(:,m) = U(:,m) / norm(U(:,m));
end
   
%Take the complex conjugate in order to plot probability density
P = U.*conj(U);
hold on


%Plot the first three Probability vectors
 plot(xval,P(:,1),'b');
 plot(xval,P(:,2),'r')
 plot(xval,P(:,3),'g')
 legend('q = 1','q = 2','q = 3')

 %Plot the Potential Function
 figure
 plot(xval,vval);
 
    
    
    
    
    